/*
 * Example for DC Motor 4 click
 *
 * Date         Apr 2017
 * Author       Djordje Rosic
 *
 * Test configuration CEC :
 *  MCU           :        CEC1702
 *  Dev. Board    :        Clicker 2 for CEC1702
 *  SW            :        mikroC PRO for ARM v5.0.0
 *
 * Description :
 *
 * This example shows basic controls of DC motor using DC motor 4 click.
 * It shows forward and reverse movement, and high and low rotation speed.
 *
 ******************************************************************************/

#include <stdint.h>

uint16_t pwmPeriod;
sbit DIR_PIN at GPIO_OUTPUT_200_207.B0;


/*
 * System Initialization
 */
void systemInit()
{
    GPIO_Digital_Output(&GPIO_OUTPUT_200_207, _GPIO_PINMASK_0);
    
    pwmPeriod = PWM10_Init(15000);                 // Set PWM frequency/period (according to the DC motor characteristics)
    PWM10_Set_Duty(pwmPeriod,  _PWM_NON_INVERTED);   // Set current duty for PWM
    PWM10_Start();

}

void main()
{

    systemInit();

    while (1)
    {
        //Forward
        DIR_PIN = 0;
        //Forward fast
        PWM10_Set_Duty(pwmPeriod,  _PWM_NON_INVERTED);
        PWM10_Start();
        Delay_ms (3000);
        //Forward slow
        PWM10_Set_Duty(pwmPeriod/2,  _PWM_NON_INVERTED);
        PWM10_Start();
        Delay_ms (3000);
        
        //Reverse
        DIR_PIN = 1;
        //Reverse fast
        PWM10_Set_Duty(pwmPeriod,  _PWM_NON_INVERTED);
        PWM10_Start();
        Delay_ms (3000);
        //Reverse slow
        PWM10_Set_Duty(pwmPeriod/2,  _PWM_NON_INVERTED);
        PWM10_Start();
        Delay_ms (3000);

    }
}
/************************************************************ END OF FILE *****/