/*
 * Example for DC Motor 4 click
 *
 * Date         Apr 2017
 * Author       Djordje Rosic
 *
 * Test configuration STM32 :
 *  MCU           :        STM32F107VCT6
 *  Dev. Board    :        EasyMx PRO v7 for STM32 ARM
 *  SW            :        mikroC PRO for ARM v5.0.0
 *
 * Description :
 *
 * This example shows basic controls of DC motor using DC motor 4 click.
 * It shows forward and reverse movement, and high and low rotation speed.
 *
 ******************************************************************************/

#include <stdint.h>

uint16_t pwmPeriod;
sbit DIR_PIN at GPIOA_ODR.B4;


/*
 * System Initialization
 */
void systemInit()
{
    GPIO_Digital_Output(&GPIOA_BASE, _GPIO_PINMASK_4);
    
    pwmPeriod = PWM_TIM5_Init(1000);                                   // Set PWM frequency/period (according to the DC motor characteristics)
    PWM_TIM5_Set_Duty(pwmPeriod,  _PWM_NON_INVERTED, _PWM_CHANNEL1);   // Set current duty for PWM
    PWM_TIM5_Start(_PWM_CHANNEL1, &_GPIO_MODULE_TIM5_CH1_PA0);          // Start PWM

}

void main()
{

    systemInit();

    while (1)
    {
        //Forward
        DIR_PIN = 0;
        //Forward fast
        PWM_TIM5_Set_Duty(pwmPeriod,  _PWM_NON_INVERTED, _PWM_CHANNEL1);
        Delay_ms (3000);
        //Forward slow
        PWM_TIM5_Set_Duty(pwmPeriod/2,  _PWM_NON_INVERTED, _PWM_CHANNEL1);
        Delay_ms (3000);
        //Reverse
        DIR_PIN = 1;
        //Reverse fast
        PWM_TIM5_Set_Duty(pwmPeriod,  _PWM_NON_INVERTED, _PWM_CHANNEL1);
        Delay_ms (3000);
        //Reverse slow
        PWM_TIM5_Set_Duty(pwmPeriod/2,  _PWM_NON_INVERTED, _PWM_CHANNEL1);
        Delay_ms (3000);

    }
}
/************************************************************ END OF FILE *****/