/*
 * Example for DC Motor 4 click
 *
 * Date         Apr 2017
 * Author       Djordje Rosic
 *
 * Test configuration TIVA :
 *  MCU           :        TM4C129XNCZAD
 *  Dev. Board    :        EasyMx PRO v7 for TIVA ARM
 *  SW            :        mikroC PRO for ARM v5.0.0
 *
 * Description :
 *
 * This example shows basic controls of DC motor using DC motor 4 click.
 * It shows forward and reverse movement, and high and low rotation speed.
 *
 ******************************************************************************/

#include <stdint.h>

uint16_t pwmPeriod;
sbit DIR_PIN at GPIO_PORTE_AHB_DATA.B4;


/*
 * System Initialization
 */
void systemInit()
{
    GPIO_Digital_Output(&GPIO_PORTE_AHB, _GPIO_PINMASK_4);

    pwmPeriod = PWM_T0CCP0_Init (1000, &_GPIO_MODULE_T0CCP0_D0_AHB);                  // Set PWM frequency/period (according to the DC motor characteristics)
    PWM_T0CCP0_Set_Duty(pwmPeriod, _PWM_INVERTED_ENABLE);
    PWM_T0CCP0_Start();


}

void main()
{

    systemInit();

    while (1)
    {
        //Forward
        DIR_PIN = 0;
        //Forward fast
        PWM_T0CCP0_Set_Duty(pwmPeriod/2, _PWM_INVERTED_ENABLE);
        Delay_ms (3000);
        //Forward slow
        PWM_T0CCP0_Set_Duty(pwmPeriod, _PWM_INVERTED_ENABLE);
        Delay_ms (3000);
        //Reverse
        DIR_PIN = 1;
        //Reverse fast
        PWM_T0CCP0_Set_Duty(pwmPeriod/2, _PWM_INVERTED_ENABLE);
        Delay_ms (3000);
        //Reverse slow
        PWM_T0CCP0_Set_Duty(pwmPeriod, _PWM_INVERTED_ENABLE);
        Delay_ms (3000);

    }
}
/************************************************************ END OF FILE *****/